#!/bin/sh
NS_HOST=myHD
APKG_PATH=/usr/local/AppCentral/${NS_HOST}
APKG_FOLDER=/usr/local/
UVER=$(/usr/bin/confutil -get ${APKG_PATH}/${NS_HOST}.conf ${NS_HOST} UVER)
MYHD_BIN=${APKG_PATH}/bin
CHROOT_PATH=${APKG_FOLDER}/.${NS_HOST}/${UVER}
PACKAGE_FOLDER=/share/Public/${NS_HOST}_package
EXCH_FOLDER=${APKG_PATH}/${NS_HOST}_temp
APPS_PATH=${APKG_PATH}/${NS_HOST}_qpkg/Apps
GEN_APKG_PATH=${APKG_PATH}/${NS_HOST}_qpkg/qpkg

BLUE="\033[0;36m"
NC="\033[0m"
RED="\033[0;31m"

FILE_NAME="${1}"
TAR_FILE_NAME=""
APKG_NAME="${2}"

test_apkg_up(){
	### TEST if apkg is Enable
	APKG_ENABLE=$(/usr/sbin/apkg --info-installed ${NS_HOST} | grep 'Enabled:' | awk '{print $2}')
	if [ "$APKG_ENABLE" != "Yes" ] ; then
		echo "Hum! ${NS_HOST} is NOT Enable"
		exit 1
	fi
}

test_ubuntu_run(){
### test if ${NS_HOST} is running
if [ ! -e /tmp/${NS_HOST}.pid ] ; then
	echo "Hum: ${NS_HOST} is NOT RUNNING ... please start it before installing packages "
	exit 1
fi
}

validate_folder_struct(){
	if [ ! -e ${PACKAGE_FOLDER}/in_install ] ; then
		mkdir -p ${PACKAGE_FOLDER}/in_install
	fi
	if [ ! -e ${PACKAGE_FOLDER}/installed ] ; then
		mkdir -p ${PACKAGE_FOLDER}/installed
	fi
}

verify_files(){
	if [ ! -e ${WORKING_DIR}/${APKG_NAME}.cfg ] ; then
		echo "hum a file is missing ${F}"
		rm -f ${PACKAGE_FOLDER}/in_install/${TAR_FILE_NAME}.${NS_HOST}
		rm -rf ${EXCH_FOLDER}/${APKG_NAME}
		exit 1
	fi
	### get information
	VER=$(/usr/bin/confutil -get ${WORKING_DIR}/${APKG_NAME}.cfg ${APKG_NAME} Version)
	if [ -z "$VER" ] ; then
		echo "Version not provide force fake one"
		VER=1.0.99
	fi
	PNG=$(/usr/bin/confutil -get ${WORKING_DIR}/${APKG_NAME}.cfg ${APKG_NAME} icon256)
	if [ -z "$PNG" ] ; then
		PNG=${APKG_NAME}.png
		if [ ! -e ${WORKING_DIR}/${PNG} ] ; then
			echo "Hum! ${APKG_NAME}.png is require is not define in .cfg file"
			rm -f ${PACKAGE_FOLDER}/in_install/${TAR_FILE_NAME}.${NS_HOST}
			rm -rf ${EXCH_FOLDER}/${APKG_NAME}
			exit 1
		fi
		/usr/bin/confutil -set ${WORKING_DIR}/${APKG_NAME}.cfg ${APKG_NAME} icon256 ${PNG}
	else
		if [ ! -e ${WORKING_DIR}/${PNG} ] ; then
			echo "Hum! ${PNG} is require is not define in .cfg file"
			rm -f ${PACKAGE_FOLDER}/in_install/${TAR_FILE_NAME}.${NS_HOST}
			rm -rf ${EXCH_FOLDER}/${APKG_NAME}
			exit 1
		fi
	fi
	SHELL_SCRIPT=$(/usr/bin/confutil -get ${WORKING_DIR}/${APKG_NAME}.cfg ${APKG_NAME} Shell)
	if [ -z "$SHELL_SCRIPT" ] ; then
		SHELL_SCRIPT=${APKG_NAME}.sh
		if [ ! -e ${WORKING_DIR}/${SHELL_SCRIPT} ] ; then
			echo "Hum! ${SHELL_SCRIPT} is require is not define in .cfg file"
			rm -f ${PACKAGE_FOLDER}/in_install/${TAR_FILE_NAME}.${NS_HOST}
			rm -rf ${EXCH_FOLDER}/${APKG_NAME}
			exit 1
		fi
		/usr/bin/confutil -set ${WORKING_DIR}/${APKG_NAME}.cfg ${APKG_NAME} Shell ${SHELL_SCRIPT}
	else
		if [ ! -e ${WORKING_DIR}/${SHELL_SCRIPT} ] ; then
			echo "Hum! ${SHELL_SCRIPT} is require is not define in .cfg file"
			rm -f ${PACKAGE_FOLDER}/in_install/${TAR_FILE_NAME}.${NS_HOST}
			rm -rf ${EXCH_FOLDER}/${APKG_NAME}
			exit 1
		fi
	fi
	FOND=$(/usr/bin/confutil -get ${WORKING_DIR}/${APKG_NAME}.cfg ${APKG_NAME} Fond)
		if [ -z "$FOND" ] ; then
			echo "force light gray background for Asportal icon"
			FOND=fond_gris_clair.png
			/usr/bin/confutil -set ${WORKING_DIR}/${APKG_NAME}.cfg ${APKG_NAME} Fond ${FOND}
		else
			case "$FOND" in
				fond_bleu.png|fond_gris.png|fond_gris_clair.png|fond_noir.png|fond_vert.png|fond_jaune.png)
					echo "Background color exist : $FOND "
				;;
				*)
					echo " Unknow background : $FOND ... force light gray background for Asportal icon"
					FOND=fond_gris_clair.png
					/usr/bin/confutil -set ${WORKING_DIR}/${APKG_NAME}.cfg ${APKG_NAME} Fond ${FOND}
				;;	
			esac
		fi
	CTRL=$(/usr/bin/confutil -get ${WORKING_DIR}/${APKG_NAME}.cfg ${APKG_NAME} Ctrl)
	if [ -z "$CTRL" ] ; then
		CTRL="default"
		/usr/bin/confutil -set ${WORKING_DIR}/${APKG_NAME}.cfg ${APKG_NAME} Ctrl ${CTRL}
	else
		case "$CTRL" in
			asportal|asremote|chrome|default|game|xbmc|system|youtube)
				echo "controle exist : $CTRL "
			;;
			*)
				echo "Unknown controle $CTRL force default "
				CTRL="default"
				/usr/bin/confutil -set ${WORKING_DIR}/${APKG_NAME}.cfg ${APKG_NAME} Ctrl ${CTRL}
			;;
		esac
	fi 
}

usage(){
	echo "Usage : (DELIVERY_TAR_FILE_NAME name format : Package_name.${NS_HOST})"
	echo -e "$0 ${BLUE}DELIVERY_TAR_FILE_NAME [PACKAGE_NAME] ${NC}] ... if PACKAGE_NAME is not provide use DELIVERY_TAR_FILE_NAME(without .${NS_HOST} extension) as PACKAGE_NAME "
	echo -e "... ... Tar file ${BLUE}MUST${NC} contains a folder name : PACKAGE_NAME "
	echo "... ... DELIVERY_TAR_FILE_NAME MUST BE in ${PACKAGE_FOLDER} directory "
	echo "... ... DELIVERY_TAR_FILE_NAME MUST BE have extension : .${NS_HOST} "
	echo "... ... DELIVERY_TAR_FILE_NAME is the PACKAGE_NAME OR a PACKAGE_NAME MUST be provide"
	echo -e "... ... ex. : $0 ${BLUE}chrome${NC} ... tar file is ${BLUE}chrome.${NS_HOST}${NC} AND implicit PACKAGE_NAME is ${BLUE}chrome${NC}"
	echo -e "... ... OR : $0 ${RED}chrome_with_pulse chrome${NC} ... tar file is name ${RED}chrome_with_pulse.${NS_HOST}${NC} BUT package is : ${RED}chrome${NC}"
	exit 1
}

test_apkg_up
test_ubuntu_run
validate_folder_struct

### require a tar file package name
if [ -z "${FILE_NAME}" ] ; then
	usage
fi

### extract  extension of TAR_FILE_NAME ... verify it's ${NS_HOST} then extract basename without extension
if [ "$(echo "${FILE_NAME##*.}")" != "${NS_HOST}" ] ; then
	echo "Tar file MUST have .${NS_HOST} as extension of the file name"
	exit 1
else
	TAR_FILE_NAME=$(basename ${FILE_NAME} .${FILE_NAME##*.} )
fi

if [ -z "${APKG_NAME}" ] ; then
	APKG_NAME="${TAR_FILE_NAME}"
fi
### require a tar gz named PACKAGE_NAME.${NS_HOST}
if [ ! -e ${PACKAGE_FOLDER}/${TAR_FILE_NAME}.${NS_HOST} ] ; then
	echo "Hum ${TAR_FILE_NAME}.${NS_HOST} file is NOT present in ${PACKAGE_FOLDER} folder"
	exit 1
fi

### test if a package folder already exist before untar
if [ -e ${EXCH_FOLDER}/${APKG_NAME} ] ; then
	echo "a version of ${APKG_NAME} exist in ${EXCH_FOLDER} ??? I delete them ..."
	rm -rf ${EXCH_FOLDER}/${APKG_NAME}
fi

### extract the tar 
tar xzf ${PACKAGE_FOLDER}/${TAR_FILE_NAME}.${NS_HOST} -C "${EXCH_FOLDER}"

if [ -e ${PACKAGE_FOLDER}/in_install/${TAR_FILE_NAME}.${NS_HOST} ] ; then
	rm -f ${PACKAGE_FOLDER}/in_install/${TAR_FILE_NAME}.${NS_HOST}
fi
mv ${PACKAGE_FOLDER}/${TAR_FILE_NAME}.${NS_HOST} ${PACKAGE_FOLDER}/in_install/${TAR_FILE_NAME}.${NS_HOST}

### verify that tar have create the attended folder 
if [ ! -e ${EXCH_FOLDER}/${APKG_NAME} ] ; then
	echo "Hum! strange ${APKG_NAME} don't exist after the tar BIG problem ... check please "
	rm -f ${PACKAGE_FOLDER}/in_install/${TAR_FILE_NAME}.${NS_HOST}
	exit 1
fi

WORKING_DIR="${EXCH_FOLDER}/${APKG_NAME}"
PNG=""
VER=""
SHELL_SCRIPT=""
FOND=""
CTRL=""
### verify minimum file are present 
verify_files

### now we can start the installation part if exist
if [ -e ${EXCH_FOLDER}/${APKG_NAME}/install.sh ] ; then
	${EXCH_FOLDER}/${APKG_NAME}/install.sh
	if [ $? -eq 0 ] ; then
		echo "Install part for ${APKG_NAME} seem to finish without any error ... good "
	else
		echo "Hum have a look before ... seem an error occurs during install phase ... "
		rm -f ${PACKAGE_FOLDER}/in_install/${TAR_FILE_NAME}.${NS_HOST}
		rm -rf ${EXCH_FOLDER}/${APKG_NAME}
		exit 1
	fi
fi

### Now we generate the Asportal APKG 
mkdir ${APPS_PATH}/${APKG_NAME}
cp -p ${WORKING_DIR}/${APKG_NAME}.cfg ${WORKING_DIR}/${PNG} ${WORKING_DIR}/${SHELL_SCRIPT} ${APPS_PATH}/${APKG_NAME}/
if [ -e ${GEN_APKG_PATH}/${APKG_NAME} ] ; then
	${MYHD_BIN}/apkg_mngt.sh delete ${APKG_NAME}
fi
${MYHD_BIN}/apkg_mngt.sh create ${APKG_NAME}
${MYHD_BIN}/apkg_mngt.sh install ${APKG_NAME}
###
if [ -e ${PACKAGE_FOLDER}/installed/${TAR_FILE_NAME}.${NS_HOST} ] ; then
	rm -f ${PACKAGE_FOLDER}/installed/${TAR_FILE_NAME}.${NS_HOST}
fi
mv ${PACKAGE_FOLDER}/in_install/${TAR_FILE_NAME}.${NS_HOST} ${PACKAGE_FOLDER}/installed/${TAR_FILE_NAME}.${NS_HOST}
